# Generated by roxygen2: do not edit by hand

S3method(print,robust_lpa)
S3method(print,summary.robust_lpa)
S3method(summary,robust_lpa)
export(bch_robust)
export(blrt_robust)
export(estimate_profiles_robust)
export(plot_mcmc_chains)
export(plot_robust_lpa)
export(robust_lpa)
export(robust_mean)
importFrom(Rcpp,sourceCpp)
importFrom(stats,qchisq)
importFrom(stats,rnorm)
importFrom(stats,runif)
importFrom(utils,modifyList)
useDynLib(RobustLPA, .registration = TRUE)
