# Generated by using Rcpp::compileAttributes() -> do not edit by hand
# Generator token: 10BE3573-1514-4C36-9D1C-5A225CD40393

robust_mean_cpp <- function(X, threshold) {
    .Call(`_RobustLPA_robust_mean_cpp`, X, threshold)
}

mahalanobis_cpp <- function(X, mu, Sigma) {
    .Call(`_RobustLPA_mahalanobis_cpp`, X, mu, Sigma)
}

huber_weights_cpp <- function(squared_dists, chi_sq_cutoff) {
    .Call(`_RobustLPA_huber_weights_cpp`, squared_dists, chi_sq_cutoff)
}

robust_update_cpp <- function(X, z, w) {
    .Call(`_RobustLPA_robust_update_cpp`, X, z, w)
}

dmvnorm_cpp <- function(X, mu, Sigma) {
    .Call(`_RobustLPA_dmvnorm_cpp`, X, mu, Sigma)
}

dmvnorm_fiml_cpp <- function(X, mu, Sigma) {
    .Call(`_RobustLPA_dmvnorm_fiml_cpp`, X, mu, Sigma)
}

mahalanobis_fiml_cpp <- function(X, mu, Sigma) {
    .Call(`_RobustLPA_mahalanobis_fiml_cpp`, X, mu, Sigma)
}

huber_weights_fiml_cpp <- function(X, squared_dists, alpha = 0.05) {
    .Call(`_RobustLPA_huber_weights_fiml_cpp`, X, squared_dists, alpha)
}

robust_update_fiml_cpp <- function(X, z, w) {
    .Call(`_RobustLPA_robust_update_fiml_cpp`, X, z, w)
}

